@@ -67,13 +67,16 @@ sub print_view {
 }
 
 
-sub div_editable_value{
+sub div_editable_value {
   my $self = shift;
   my $name = shift;
   
+  my @cls = qw/editable-value inln/;
+  push @cls, @{ $self->{_editable_value_extra_classes} || [] };
+  
   return $self->div_clickable(
     
-    '<div class="editable-value inln">' .
+    '<div class="'.join(' ',@cls).'">' .
       '<div class="field-name" style="display:none;">' . $name . '</div>' .
       (shift) .
     '</div>'
@@ -262,6 +265,12 @@ has 'autofield', is => 'ro', lazy => 1, default => sub {
   );
 }, isa => 'RapidApp::Module::AppDV::RecAutoload';
 
+has 'column_info', is => 'ro', lazy => 1, default => sub {
+  my $self = shift;
+  return RapidApp::Module::AppDV::RecAutoload->new( 
+    process_coderef => $self->_autofield_processor({ special => 'column_info' })
+  );
+}, isa => 'RapidApp::Module::AppDV::RecAutoload';
 
 sub _autofield_processor {
   my $self = shift;
@@ -272,19 +281,18 @@ sub _autofield_processor {
       $display = $name unless ($display);
       my $Column = $self->AppDV->get_column($name) or return '';
       
+      if (my $special = $cnf->{special}) {
+        return clone( $Column ) if ($special eq 'column_info');
+        
+        # future use ...
+        die "Bad/unknown 'special' code $special";
+      }
+      
       my $ro = $Column->editor ? 0 : 1;
       
       $ro = 1 if ($cnf->{ro});
       
-      # -- TODO: this breaks create without update unless "allow_add" is specifically set on the column
-      # Needs fixed... probably the best way to handle it is to dynamically turn on "allow_add" when
-      # it isn't explicitly set but it should otherwise be addable (i.e. set in creatable_colspec)
-      $ro = 1 if (
-        defined $Column->allow_edit and
-        ! jstrue($Column->allow_edit) and
-        ! jstrue($Column->allow_add)
-      );
-      # --
+      $ro = 1 unless ($Column->allow_edit || $Column->allow_add);
       
       # -- Only allow the same column through as editable once per template processing
       if(my $hsh = $self->AppDV->{_template_process_ctx}){
@@ -306,6 +314,15 @@ sub _autofield_processor {
       # read-only:
       return $self->div_wrapper('{' . $display . '}') if ($ro);
       
+      # -- New: add 'no-edit' to the list of css classes that will be applied to the div
+      # if this column is non-editable. This only matters when allow_add is true, meaning
+      # the column cannot be edited, except when its for a new record. This CSS class is
+      # used to distinguish between these cases when allow_edit and allow_add disagree
+      my @cls = ();
+      push @cls, 'no-edit' unless($Column->allow_edit);
+      local $self->{_editable_value_extra_classes} = \@cls;
+      # --
+      
       # -- TODO: refactor AppDV for all the changes that came with TableSpec
       # in the mean time, this makes sure the editor/field isn't too small
       $config->{minHeight} = 22 unless ($config->{minHeight});
@@ -511,7 +528,7 @@ sub toggle {
   my $self = shift;
   return {
     edit => $self->div_clickable(
-      '<div class="edit-record-toggle inln">' .
+      '<div class="edit-record-toggle default inln">' .
         '<div class="edit">Edit</div>' .
         '<div class="save">Save</div>' .
         '<div class="cancel">Cancel</div>' .
